@@ -35,7 +35,7 @@ use overload 'bool' => sub () { 1 };
 
 use vars qw{$VERSION %_PARENT};
 BEGIN {
-	$VERSION = '0.828';
+	$VERSION = '0.829';
 
 	# Master Child -> Parent index
 	%_PARENT = ();
@@ -52,11 +52,11 @@ BEGIN {
 
 =head2 significant
 
-Because we treat whitespace and other non-code items as tokens (in order to
+Because we treat whitespace and other non-code items as Tokens (in order to
 be able to "round trip" the PPI::Document back to a file) the C<significant>
-allows us to distinguish between tokens that form a part of the code, and
-tokens that arn't significant, such as whitespace, POD, or the portion of 
-a file after the __END__ token.
+method allows us to distinguish between tokens that form a part of the code,
+and tokens that arn't significant, such as whitespace, POD, or the portion
+of a file after (and including) the __END__ token.
 
 =cut
 
@@ -66,8 +66,9 @@ sub significant { 1 }
 
 =head2 tokens
 
-The C<tokens> method returns a flat list of PPI::Token object for the
-PPI::Element, essentially undoing the lexing of the document.
+The C<tokens> method returns a list of PPI::Token objects for the
+Element, essentially getting back that part of the document as if it had not
+been lexed.
 
 =cut
 
@@ -77,8 +78,10 @@ sub tokens { $_[0] }
 
 =head2 content
 
-For ANY PPI::element, the C<content> method will reconstitute the raw source
-code for it as a single string.
+For B<any> PPI::Element, the C<content> method will reconstitute the raw source
+code for it as a single string. This method is also the method used for
+overloading stringification. When an Element is used in a double-quoted string
+for example, this is the method that is called.
 
 Returns the code as a string, or C<undef> on error.
 
@@ -97,12 +100,11 @@ sub content { defined $_[0]->{content} ? $_[0]->{content} : '' }
 
 =head2 parent
 
-Elements themselves are not intended to contain other elements, that is left
+Elements themselves are not intended to contain other Elements, that is left
 to the L<PPI::Node|PPI::Node> abstract class, a subclass of PPI::Element.
-However, all elements can be contained within a higher ::Node object.
+However, all Elements can be contained B<within> a parent Node.
 
-If an ::Element object is within a ::Node, the C<parent> method returns the
-patent ::Node object.
+If an Element is within a parent Node, the C<parent> method returns the Node.
 
 =cut
 
@@ -113,13 +115,12 @@ sub parent { $_PARENT{refaddr shift} }
 =head2 statement
 
 For a PPI::Element that is contained (at some depth) within a PPI::Statment,
-the C<statement> method will return the first parent PPI::Statement object
-'above' the PPI::Element.
+the C<statement> method will return the first parent Statement object
+lexically 'above' the Element.
 
 Returns a L<PPI::Statement|PPI::Statement> object, which may be the same
-PPI::Element if the element is itself a PPI::Statement object. Returns false
-if the Element is not within a PPI::Statement, or is not itself a
-PPI::Statement.
+Element if the Element is itself a PPI::Statement object. Returns false
+if the Element is not within a Statement and is not itself a Statement.
 
 =cut
 
@@ -135,12 +136,14 @@ sub statement {
 
 =head2 top
 
-For a PPI::Element that is contained within other ::Elements,
-the C<top> method will return the top-level ::Element in the tree that this
-is part of.
+For a PPI::Element that is contained within a PDOM tree, the C<top> method
+will return the top-level Node in the tree. Most of the time this should be
+a L<PPI::Document> object, however this will not always be so. For example,
+if a subroutine has been removed from its Document, to be moved to another
+Document.
 
-Returns the top-most PPI::Element object, which may be the same PPI::Element
-if it is not within any other ::Elements.
+Returns the top-most PDOM object, which may be the same Element, if it is
+not within any parent PDOM object.
 
 =cut
 
@@ -154,8 +157,8 @@ sub top {
 
 =pod
 
-For a PPI::Element that is contained within a PPI::Document object,
-the C<top> method will return the top-level Document for the Element.
+For an Element that is contained within a L<PPI::Document> object,
+the C<document> method will return the top-level Document for the Element.
 
 Returns the PPI::Document for this Element, or false if the Element is not
 contained within a Document.
@@ -164,7 +167,7 @@ contained within a Document.
 
 sub document {
 	my $top = shift->top;
-	isa($top, 'PPI::Document') ? $top : '';
+	isa($top, 'PPI::Document') and $top;
 }
 
 =cut
@@ -173,9 +176,9 @@ sub document {
 
 =head2 next_sibling
 
-All PPI::Node objects contain a number of PPI::Elements. The C<next_sibling>
-method returns the PPI::Element immediately after the current one, or false
-if there is no next sibling.
+All L<PPI::Node> objects (specifically, our parent Node) contain a number of
+PPI::Element objects. The C<next_sibling> method returns the PPI::Element
+immediately after the current one, or false if there is no next sibling.
 
 =cut
 
@@ -222,9 +225,10 @@ sub snext_sibling {
 
 =head2 previous_sibling
 
-All PPI::Node objects contain a number of PPI::Element object. The
-C<previous_sibling> method returns the PPI::Element immediately before the
-current one, or false if there is no previous PPI::Element object.
+All L<PPI::Node> objects (specifically, our parent Node) contain a number of
+PPI::Element objects. The C<previous_sibling> method returns the Element
+immediately before the current one, or false if there is no 'previous'
+PPI::Element object.
 
 =cut
 
@@ -270,15 +274,17 @@ sub sprevious_sibling {
 
 As a support method for higher-order algorithms that deal specifically with
 tokens and actual Perl content, the C<next_token> method finds the PPI::Token
-object that is immediately after the current PPI::Element object, even if it
-is not within the same parent PPI::Node object as this one.
+object that is immediately after the current Element, even if it is not within
+the same parent L<PPI::Node|PPI::Node> as the one for which the method is
+being called.
 
-Note that this is not defined as a PPI::Token-only method, because it can be
-useful to find the next token that is after, say, a PPI::Statement, although
-obviously it would be useless to want the next token after a PPI::Document.
+Note that this is B<not> defined as a PPI::Token-specific method, because it
+can be useful to find the next token that is after, say, a
+L<PPI::Statement|PPI::Statement>, although obviously it would be useless to
+want the next token after a L<PPI::Document|PPI::Document>.
 
-Returns a PPI::Token object, or false if there are no more tokens after
-the PPI::Element.
+Returns a PPI::Token object, or false if there are no more token after
+the Element.
 
 =cut
 
@@ -298,7 +304,9 @@ sub next_token {
 	###       is the ONLY class to inherit from PPI::Element other
 	###       than PPI::Node. This is because first_element is really
 	###       a PPI::Node method, NOT a PPI::Element method, so we are
-	###       using it in a slightly unsafe context.
+	###       using it in a slightly unsafe context. Again though, in
+	###       the class structure as of the time this method was written,
+	###       this is safe.
 	while ( ! isa($Element, 'PPI::Token') ) {
 		defined($Element = $Element->first_element) or return '';
 	}
@@ -312,15 +320,15 @@ sub next_token {
 
 As a support method for higher-order algorithms that deal specifically with
 tokens and actual Perl content, the C<previous_token> method finds the
-PPI::Token object that is immediately before the current PPI::Element object,
-even if it is not within the same parent PPI::Node object as this one.
+PPI::Token object that is immediately before the current Element, even if it
+is not within the same parent L<PPI::Node|PPI::Node> as this one.
 
 Note that this is not defined as a PPI::Token-only method, because it can be
 useful to find the token is before, say, a PPI::Statement, although
 obviously it would be useless to want the next token before a  PPI::Document
 
 Returns a PPI::Token object, or false if there are no more tokens before
-the PPI::Element.
+the Element.
 
 =cut
 
@@ -354,8 +362,9 @@ sub previous_token {
 =head2 clone
 
 As per the Clone module, the C<clone> method makes a perfect copy of
-an Element object. In the generic case, the implementation if done using
-the Clone module's mechanism itself.
+an Element object. In the generic case, the implementation is done using
+the Clone module's mechanism itself. In higher-order cases, such as for
+Nodes, there is more work involved to keep the parent-child links intact.
 
 =cut
 
@@ -371,8 +380,8 @@ The C<insert_before> method allows you to insert lexical perl content, in
 the form of PPI::Element objects, before the calling Element. You need to be
 very careful when modifying perl code, as it's easy to break things.
 
-This method is not yet implemented, mainly due to the difficulty in making
-it just DWYM.
+B<This method is not yet implemented, mainly due to the difficulty in making
+it Do What You Mean.>
 
 =cut
 
@@ -380,7 +389,7 @@ sub insert_before {
 	die "The ->insert_before method has not been implemented";
 }
 
-# The internal version, which trust the data we are given
+# The internal version, which trusts the data we are given
 sub _insert_before {
 	my $self = shift;
 	
@@ -391,11 +400,11 @@ sub _insert_before {
 =head2 insert_after @Elements
 
 The C<insert_after> method allows you to insert lexical perl content, in
-the form of PPI::Element objects, before the calling Element. You need to be
+the form of PPI::Element objects, after the calling Element. You need to be
 very careful when modifying perl code, as it's easy to break things.
 
-This method is not yet implemented, mainly due to the difficulty in making
-it just DWYM.
+B<This method is not yet implemented, mainly due to the difficulty in making
+it Do What You Mean.>
 
 =cut
 
@@ -403,7 +412,7 @@ sub insert_after {
 	die "The ->insert_after method has not been implemented";
 }
 
-# The internal version, which trust the data we are given
+# The internal version, which trusts the data we are given
 sub _insert_after {
 	my $self = shift;
 	
@@ -413,8 +422,8 @@ sub _insert_after {
 
 =head2 remove
 
-For a given PPI::Element, the C<remove> method will remove it from it's
-parent INTACT, along with all of it's children.
+For a given PPI::Element, the C<remove> method will remove it from its
+parent B<intact>, along with all of its children.
 
 Returns the Element itself as a convenience, or C<undef> if an error
 occurs while trying to remove the Element.
@@ -431,8 +440,9 @@ sub remove {
 
 =head2 delete
 
-For a given PPI::Element, the C<remove> method will remove it from it's
-parent, deleting the Element and all of it's children.
+For a given Element, the C<remove> method will remove it from its
+parent, immediately deleting the Element and all of its children (if it has
+any).
 
 Returns true if the Element was successfully deleted, or C<undef> if
 an error occurs while trying to remove the Element.
@@ -451,12 +461,13 @@ sub delete {
 =head2 location
 
 If the Element exists within a L<PPI::Document|PPI::Document> that has
-indexed the Element locations, the C<location> method will return the
-location of the Element.
+indexed the Element locations using C<PPI::Document::index_locations>, the
+C<location> method will return the location of the first character of the
+Element within the Document.
 
 Returns the location as a reference to a two-element array in the form
 C<[ $line, $col ]>. The values are in a human format, with the first
-character of the file located at C<[ 1, 1 ]>. Returns undef on error,
+character of the file located at C<[ 1, 1 ]>. Returns C<undef> on error,
 or if the PPI::Document object has not been indexed.
 
 =cut
@@ -487,3 +498,34 @@ sub __eq {
 }
 
 1;
+
+=head1 TO DO
+
+It would be nice if C<location> could be used in an ad-hoc manner. That is,
+if called on an Element within a Document that has not been indexed, it will
+do a one-off calculation to find the location. It might be very painful if
+someone started using it a lot, without remembering to index the document,
+but it would be handy for things that are only likely to use it once, such
+as error handlers.
+
+=head1 SUPPORT
+
+See the L<support section|PPI::Manual/SUPPORT> in the main PPI Manual
+
+=head1 AUTHOR
+
+Adam Kennedy (Maintainer), L<http://ali.as/>, cpan@ali.as
+
+=head1 COPYRIGHT
+
+Thank you to Phase N (L<http://phase-n.com/>) for permitting
+the open sourcing and release of this distribution.
+
+Copyright (c) 2004 Adam Kennedy. All rights reserved.
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
+
+The full text of the license can be found in the
+LICENSE file included with this module.
+
+=cut
