@@ -25,7 +25,7 @@ use PPI::Token::Whitespace    ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.828';
+	$VERSION = '0.829';
 }
 
 
@@ -151,7 +151,7 @@ sub _isa {
 package PPI::Token::Data;
 
 BEGIN {
-	$PPI::Token::Data::VERSION = '0.828';
+	$PPI::Token::Data::VERSION = '0.829';
 	@PPI::Token::Data::ISA     = 'PPI::Token';
 }
 
@@ -166,7 +166,7 @@ sub _on_char { 1 }
 package PPI::Token::End;
 
 BEGIN {
-	$PPI::Token::End::VERSION = '0.828';
+	$PPI::Token::End::VERSION = '0.829';
 	@PPI::Token::End::ISA     = 'PPI::Token';
 }
 
@@ -212,7 +212,7 @@ sub _on_line_start {
 package PPI::Token::Label;
 
 BEGIN {
-	$PPI::Token::Label::VERSION = '0.828';
+	$PPI::Token::Label::VERSION = '0.829';
 	@PPI::Token::Label::ISA     = 'PPI::Token';
 }
 
@@ -226,7 +226,7 @@ BEGIN {
 package PPI::Token::Structure;
 
 BEGIN {
-	$PPI::Token::Structure::VERSION = '0.828';
+	$PPI::Token::Structure::VERSION = '0.829';
 	@PPI::Token::Structure::ISA     = 'PPI::Token';
 }
 
@@ -269,7 +269,7 @@ sub _opposite { $match[ord $_[0]->{content} ] }
 package PPI::Token::ArrayIndex;
 
 BEGIN {
-	$PPI::Token::ArrayIndex::VERSION = '0.828';
+	$PPI::Token::ArrayIndex::VERSION = '0.829';
 	@PPI::Token::ArrayIndex::ISA     = 'PPI::Token';
 }
 
@@ -297,7 +297,7 @@ sub _on_char {
 package PPI::Token::Cast;
 
 BEGIN {
-	$PPI::Token::Cast::VERSION = '0.828';
+	$PPI::Token::Cast::VERSION = '0.829';
 	@PPI::Token::Cast::ISA     = 'PPI::Token';
 }
 
@@ -313,11 +313,11 @@ sub _on_char {
 #####################################################################
 # Subroutine prototype
 
-package PPI::Token::SubPrototype;
+package PPI::Token::Prototype;
 
 BEGIN {
-	$PPI::Token::SubPrototype::VERSION = '0.828';
-	@PPI::Token::SubPrototype::ISA     = 'PPI::Token';
+	$PPI::Token::Prototype::VERSION = '0.829';
+	@PPI::Token::Prototype::ISA     = 'PPI::Token';
 }
 
 sub _on_char {
@@ -335,6 +335,13 @@ sub _on_char {
 	$t->_finalize_token->_on_char( $t );
 }
 
+sub prototype {
+	my $self = shift;
+	my $prototype = $self->content;
+	$prototype =~ s/\(\)\s//g; # Strip brackets and whitespace
+	$prototype;
+}
+
 
 
 
@@ -347,7 +354,7 @@ package PPI::Token::Separator;
 # These don't have any method, they are just for identification
 
 BEGIN {
-	$PPI::Token::Separator::VERSION = '0.828';
+	$PPI::Token::Separator::VERSION = '0.829';
 	@PPI::Token::Separator::ISA     = 'PPI::Token::Word';
 }
 
@@ -362,7 +369,7 @@ BEGIN {
 package PPI::Token::Quote::Single;
 
 BEGIN {
-	$PPI::Token::Quote::Single::VERSION = '0.828';
+	$PPI::Token::Quote::Single::VERSION = '0.829';
 	@PPI::Token::Quote::Single::ISA     = 'PPI::Token::Quote::Simple';
 }
 
@@ -370,7 +377,7 @@ BEGIN {
 package PPI::Token::Quote::Double;
 
 BEGIN {
-	$PPI::Token::Quote::Single::VERSION = '0.828';
+	$PPI::Token::Quote::Single::VERSION = '0.829';
 	@PPI::Token::Quote::Double::ISA     = 'PPI::Token::Quote::Simple';
 }
 
@@ -403,7 +410,7 @@ sub simplify {
 package PPI::Token::Quote::Dashed;
 
 BEGIN {
-	$PPI::Token::Quote::Dashed::VERSION = '0.828';
+	$PPI::Token::Quote::Dashed::VERSION = '0.829';
 	@PPI::Token::Quote::Dashed::ISA     = 'PPI::Token::Quote';
 }
 
@@ -433,7 +440,7 @@ sub _on_char {
 package PPI::Token::Quote::Execute;
 
 BEGIN {
-	$PPI::Token::Quote::Execute::VERSION = '0.828';
+	$PPI::Token::Quote::Execute::VERSION = '0.829';
 	@PPI::Token::Quote::Execute::ISA     = 'PPI::Token::Quote::Simple';
 }
 
@@ -441,7 +448,7 @@ BEGIN {
 package PPI::Token::Quote::OperatorSingle;
 
 BEGIN {
-	$PPI::Token::Quote::OperatorSingle::VERSION = '0.828';
+	$PPI::Token::Quote::OperatorSingle::VERSION = '0.829';
 	@PPI::Token::Quote::OperatorSingle::ISA     = 'PPI::Token::Quote::Full';
 }
 
@@ -449,7 +456,7 @@ BEGIN {
 package PPI::Token::Quote::OperatorDouble;
 
 BEGIN {
-	$PPI::Token::Quote::OperatorDouble::VERSION = '0.828';
+	$PPI::Token::Quote::OperatorDouble::VERSION = '0.829';
 	@PPI::Token::Quote::OperatorDouble::ISA     = 'PPI::Token::Quote::Full';
 }
 
@@ -457,7 +464,7 @@ BEGIN {
 package PPI::Token::Quote::OperatorExecute;
 
 BEGIN {
-	$PPI::Token::Quote::OperatorExecute::VERSION = '0.828';
+	$PPI::Token::Quote::OperatorExecute::VERSION = '0.829';
 	@PPI::Token::Quote::OperatorExecute::ISA     = 'PPI::Token::Quote::Full';
 }
 
@@ -465,7 +472,7 @@ BEGIN {
 package PPI::Token::Quote::Words;
 
 BEGIN {
-	$PPI::Token::Quote::Words::VERSION = '0.828';
+	$PPI::Token::Quote::Words::VERSION = '0.829';
 	@PPI::Token::Quote::Words::ISA     = 'PPI::Token::Quote::Full';
 }
 
@@ -473,7 +480,7 @@ BEGIN {
 package PPI::Token::Quote::Regex;
 
 BEGIN {
-	$PPI::Token::Quote::Regex::VERSION = '0.828';
+	$PPI::Token::Quote::Regex::VERSION = '0.829';
 	@PPI::Token::Quote::Regex::ISA     = 'PPI::Token::Quote::Full';
 }
 
@@ -481,7 +488,7 @@ BEGIN {
 package PPI::Token::Regex::Match;
 
 BEGIN {
-	$PPI::Token::Regex::Match::VERSION = '0.828';
+	$PPI::Token::Regex::Match::VERSION = '0.829';
 	@PPI::Token::Regex::Match::ISA     = 'PPI::Token::Quote::Full';
 }
 
@@ -490,7 +497,7 @@ BEGIN {
 package PPI::Token::Regex::Pattern;
 
 BEGIN {
-	$PPI::Token::Regex::Pattern::VERSION = '0.828';
+	$PPI::Token::Regex::Pattern::VERSION = '0.829';
 	@PPI::Token::Regex::Pattern::ISA     = 'PPI::Token::Quote::Full';
 }
 
@@ -498,7 +505,7 @@ BEGIN {
 package PPI::Token::Regex::Replace;
 
 BEGIN {
-	$PPI::Token::Regex::Replace::VERSION = '0.828';
+	$PPI::Token::Regex::Replace::VERSION = '0.829';
 	@PPI::Token::Regex::Replace::ISA     = 'PPI::Token::Quote::Full';
 }
 
@@ -506,7 +513,7 @@ BEGIN {
 package PPI::Token::Regex::Transform;
 
 BEGIN {
-	$PPI::Token::Regex::Transform::VERSION = '0.828';
+	$PPI::Token::Regex::Transform::VERSION = '0.829';
 	@PPI::Token::Regex::Transform::ISA     = 'PPI::Token::Quote::Full';
 }
 
@@ -520,21 +527,21 @@ BEGIN {
 package PPI::Token::RawInput::Operator;
 
 BEGIN {
-	$PPI::Token::RawInput::Operator::VERSION = '0.828';
+	$PPI::Token::RawInput::Operator::VERSION = '0.829';
 	@PPI::Token::RawInput::Operator::ISA     = 'PPI::Token';
 }
 
 package PPI::Token::RawInput::Terminator;
 
 BEGIN {
-	$PPI::Token::RawInput::Terminator::VERSION = '0.828';
+	$PPI::Token::RawInput::Terminator::VERSION = '0.829';
 	@PPI::Token::RawInput::Terminator::ISA     = 'PPI::Token';
 }
 
 package PPI::Token::RawInput::String;
 
 BEGIN {
-	$PPI::Token::RawInput::String::VERSION = '0.828';
+	$PPI::Token::RawInput::String::VERSION = '0.829';
 	@PPI::Token::RawInput::String::ISA     = 'PPI::Token';
 }
 
